@@ -129,11 +129,12 @@ class Work:
 
                 total_allocation = 0
                 if not work.allocations:
-                    durations[work.id] = work.effort
+                    durations[work.id] = (work.effort or 0)
                     continue
                 for allocation in work.allocations:
                     total_allocation += allocation.percentage
-                durations[work.id] = work.effort / (total_allocation / 100.0)
+                durations[work.id] = ((work.effort or 0)
+                    / (total_allocation / 100.0))
 
             while leafs:
                 for work_id in leafs:
@@ -598,9 +599,8 @@ class Work:
 
                 yield sibling, delay
 
-        parent = self.parent and self.parent.id or None
         siblings = self.search([
-                ('parent', '=', parent.id)
+                ('parent', '=', self.parent.id if self.parent else None)
                 ])
 
         refkey = get_key(self)
@@ -617,8 +617,8 @@ class Work:
                     'back_leveling_delay': delay,
                     })
 
-        if parent:
-            parent.compute_dates()
+        if self.parent:
+            self.parent.compute_dates()
 
     @classmethod
     def write(cls, works, values):
